==> cost-interface-0.2.5-sources.jar: com/chinayanghe/tpm/cost/vo/in/CostHeadQueryVo.java <==
package com.chinayanghe.tpm.cost.vo.in;

import java.io.Serializable;
import java.util.Date;

import com.chinayanghe.tpm.cost.vo.FormTypeEnum;

public class CostHeadQueryVo implements Serializable{
	  private String queryNo;//查询单号
	  private String title;//标题
	  private String bigAreaCode;//大区编码
	  private String subCompCode;//分公司编码
	  private FormTypeEnum queryType=FormTypeEnum.regist;//单据类型
	  private String posCode;//登记岗位编码
	  private String costTypeCode;//费用类型编码
	  private Date startTime;//活动开始时间
	  private Date endTime;//活动结束时间
	  private String activityTypeCode;//一级活动类型编码
	  private String activitySubTypeCode;//二级活动编码
	  private String dealerCode;//经销商编码
	  private String dealerName;//经销商名称
	  private String  termCode;//终端编码
	  private String  termName;//终端名称 
	public String getQueryNo() {
		return queryNo;
	}
	public void setQueryNo(String queryNo) {
		this.queryNo = queryNo;
	}
	public String getTitle() {
		return title;
	}
	public void setTitle(String title) {
		this.title = title;
	}
	public String getBigAreaCode() {
		return bigAreaCode;
	}
	public void setBigAreaCode(String bigAreaCode) {
		this.bigAreaCode = bigAreaCode;
	}
	public String getSubCompCode() {
		return subCompCode;
	}
	public void setSubCompCode(String subCompCode) {
		this.subCompCode = subCompCode;
	}

	public FormTypeEnum getQueryType() {
		return queryType;
	}
	public void setQueryType(FormTypeEnum queryType) {
		this.queryType = queryType;
	}
	public String getPosCode() {
		return posCode;
	}
	public void setPosCode(String posCode) {
		this.posCode = posCode;
	}
	public String getCostTypeCode() {
		return costTypeCode;
	}
	public void setCostTypeCode(String costTypeCode) {
		this.costTypeCode = costTypeCode;
	}
	public Date getStartTime() {
		return startTime;
	}
	public void setStartTime(Date startTime) {
		this.startTime = startTime;
	}
	public Date getEndTime() {
		return endTime;
	}
	public void setEndTime(Date endTime) {
		this.endTime = endTime;
	}
	public String getActivityTypeCode() {
		return activityTypeCode;
	}
	public void setActivityTypeCode(String activityTypeCode) {
		this.activityTypeCode = activityTypeCode;
	}
	public String getActivitySubTypeCode() {
		return activitySubTypeCode;
	}
	public void setActivitySubTypeCode(String activitySubTypeCode) {
		this.activitySubTypeCode = activitySubTypeCode;
	}
	public String getDealerCode() {
		return dealerCode;
	}
	public void setDealerCode(String dealerCode) {
		this.dealerCode = dealerCode;
	}
	public String getDealerName() {
		return dealerName;
	}
	public void setDealerName(String dealerName) {
		this.dealerName = dealerName;
	}
	public String getTermCode() {
		return termCode;
	}
	public void setTermCode(String termCode) {
		this.termCode = termCode;
	}
	public String getTermName() {
		return termName;
	}
	public void setTermName(String termName) {
		this.termName = termName;
	}
	  
	  
}

==> cost-interface-0.3.4-sources.jar: com/chinayanghe/tpm/cost/vo/in/CostHeadQueryVo.java <==
package com.chinayanghe.tpm.cost.vo.in;

import java.io.Serializable;
import java.util.Date;

import com.chinayanghe.tpm.cost.vo.FormTypeEnum;

public class CostHeadQueryVo implements Serializable{
	  private String queryNo;//查询单号
	  private String title;//标题
	  private String bigAreaCode;//大区编码
	  private String subCompCode;//分公司编码
	  private FormTypeEnum queryType=FormTypeEnum.regist;//单据类型
	  private String posCode;//登记岗位编码
	  private String costTypeCode;//费用类型编码
	  private Date startTime;//活动开始时间
	  private Date endTime;//活动结束时间
	  private String activityTypeCode;//一级活动类型编码
	  private String activitySubTypeCode;//二级活动编码
	  private String dealerCode;//经销商编码
	  private String dealerName;//经销商名称
	  private String  termCode;//终端编码
	  private String  termName;//终端名称(此查询条件暂时无用) 
	public String getQueryNo() {
		return queryNo;
	}
	public void setQueryNo(String queryNo) {
		this.queryNo = queryNo;
	}
	public String getTitle() {
		return title;
	}
	public void setTitle(String title) {
		this.title = title;
	}
	public String getBigAreaCode() {
		return bigAreaCode;
	}
	public void setBigAreaCode(String bigAreaCode) {
		this.bigAreaCode = bigAreaCode;
	}
	public String getSubCompCode() {
		return subCompCode;
	}
	public void setSubCompCode(String subCompCode) {
		this.subCompCode = subCompCode;
	}

	public FormTypeEnum getQueryType() {
		return queryType;
	}
	public void setQueryType(FormTypeEnum queryType) {
		this.queryType = queryType;
	}
	public String getPosCode() {
		return posCode;
	}
	public void setPosCode(String posCode) {
		this.posCode = posCode;
	}
	public String getCostTypeCode() {
		return costTypeCode;
	}
	public void setCostTypeCode(String costTypeCode) {
		this.costTypeCode = costTypeCode;
	}
	public Date getStartTime() {
		return startTime;
	}
	public void setStartTime(Date startTime) {
		this.startTime = startTime;
	}
	public Date getEndTime() {
		return endTime;
	}
	public void setEndTime(Date endTime) {
		this.endTime = endTime;
	}
	public String getActivityTypeCode() {
		return activityTypeCode;
	}
	public void setActivityTypeCode(String activityTypeCode) {
		this.activityTypeCode = activityTypeCode;
	}
	public String getActivitySubTypeCode() {
		return activitySubTypeCode;
	}
	public void setActivitySubTypeCode(String activitySubTypeCode) {
		this.activitySubTypeCode = activitySubTypeCode;
	}
	public String getDealerCode() {
		return dealerCode;
	}
	public void setDealerCode(String dealerCode) {
		this.dealerCode = dealerCode;
	}
	public String getDealerName() {
		return dealerName;
	}
	public void setDealerName(String dealerName) {
		this.dealerName = dealerName;
	}
	public String getTermCode() {
		return termCode;
	}
	public void setTermCode(String termCode) {
		this.termCode = termCode;
	}
	public String getTermName() {
		return termName;
	}
	public void setTermName(String termName) {
		this.termName = termName;
	}
	  
	  
}
